; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1



;-| Super Motions |--------------------------------------------------------

[Command]
name = "EX_SCRAMBLE"
command = ~D, DF, F, x+z
time = 20

[Command]
name = "EX_OVER_EASY"
command = ~D, DF, F, z+y
time = 20

[Command]
name="SUPER1"
command=~D,DF,F,D,DF,F,x
time=30

[Command]
name="SUPER1"
command=~D,DF,F,D,DF,F,y
time=30

[Command]
name="SUPER1"
command=~D,DF,F,D,DF,F,z
time=30


[Command]
name="SUPER2"
command=~D,DF,F,D,DF,F,a
time=30

[Command]
name="SUPER2"
command=~D,DF,F,D,DF,F,b
time=30

[Command]
name="SUPER2"
command=~D,DF,F,D,DF,F,c
time=30

; PARTY WAGON
[Command]
name="SUPER3"
command=~30$B, F, x+y
time=30
[Command]
name="SUPER3"
command=~30$B, F, y+z
time=30
name="SUPER3"
command=~30$B, F, x+z
time=30
[Command]
name="SUPER3"
command=~30$B, F, ~x+y
time=30
[Command]
name="SUPER3"
command=~30$B, F, ~y+z
time=30
[Command]
name="SUPER3"
command=~30$B, F, ~x+z
time=30

[Command]
name = "JUGULARJAMB"
command = ~D, DF, F, y
time = 20

[Command]
name = "JUGULARJAMB"
command = ~D, DF, F, ~y
time = 20

[Command]
name = "OVER_EASY"
command = ~D, DF, F, z
time = 20

[Command]
name = "OVER_EASY"
command = ~D, DF, F, ~z
time = 20

;-| Special Motions |------------------------------------------------------

[Command]
name = "super jump"
command = $D, $U
time = 15

;KNOCKOUT ROLL
[Command]
name="KNOCKOUT1"
command=~D,DF,F,x
[Command]
name="KNOCKOUT1"
command=~D,DF,F,~x

[Command]
name="KNOCKOUT2"
command=~D,DF,F,y
[Command]
name="KNOCKOUT2"
command=~D,DF,F,~y

[Command]
name="KNOCKOUT3"
command=~D,DF,F,z
[Command]
name="KNOCKOUT3"
command=~D,DF,F,~z

; HEEL DROP
[Command]
name = "HEEL_a"
command =~D, DB, B,~a
time=15
[Command]
name = "HEEL_b"
command =~D, DB, B,~b
time=15
[Command]
name = "HEEL_c"
command =~D, DB, B,~c
time=15
[Command]
name = "HEEL_a"
command =~D, DB, B,a
time=15
[Command]
name = "HEEL_b"
command =~D, DB, B,b
time=15
[Command]
name = "HEEL_c"
command =~D, DB, B,c
time=15
[Command]
name = "HEEL_a"
command =~16$B,F, a
[Command]
name = "HEEL_b"
command =~16$B,F, b
[Command]
name = "HEEL_c"
command =~16$B,F, c
[Command]
name = "HEEL_a"
command =~16$B,F,~a
[Command]
name = "HEEL_b"
command =~16$B,F,~b
[Command]
name = "HEEL_c"
command =~16$B,F,~c
[Command]
name = "HEEL_a"
command =~14$DB,F,a
[Command]
name = "HEEL_b"
command =~14$DB,F,b
[Command]
name = "HEEL_c"
command =~14$DB,F,c
[Command]
name = "HEEL_a"
command =~14$B,$UF,a
[Command]
name = "HEEL_b"
command =~14$B,$UF,b
[Command]
name = "HEEL_c"
command =~14$B,$UF,c
[Command]
name = "HEEL_a"
command =~13$DB,$UF,a
[Command]
name = "HEEL_b"
command =~13$DB,$UF,b
[Command]
name = "HEEL_c"
command =~13$DB,$UF,c
[Command]
name = "HEEL_b"
command =~13$DB,$UF,b
time=15
[Command]
name = "HEEL_c"
command =~13$DB,$UF,c
time=15


; EX HEEL DROP
[Command]
name = "EXHEEL_a"
command =~16$B,F, a+c
time=15
[Command]
name = "EXHEEL_b"
command =~16$B,F, a+b
time=15
[Command]
name = "EXHEEL_c"
command =~16$B,F, b+c
time=15
[Command]
name = "EXHEEL_a"
command =~13$DB,$DF,a+c
time=15
[Command]
name = "EXHEEL_b"
command =~13$DB,$DF,a+b
time=15
[Command]
name = "EXHEEL_c"
command =~13$DB,$DF,b+c
time=15
[Command]
name = "EXHEEL_a"
command =~13$DB,$UF,a+c
time=15
[Command]
name = "EXHEEL_b"
command =~13$DB,$UF,a+b
time=15
[Command]
name = "EXHEEL_c"
command =~13$DB,$UF,b+c
time=15
[Command]
name = "EXHEEL_c"
command =~10$DB,U,b+c
time=15
[Command]
name = "EXHEEL_a"
command =~10$DB,$U,a+c
time=15
[Command]
name = "EXHEEL_b"
command =~10$DB,$U,a+b
time=15
[Command]
name = "EXHEEL_a"
command =~B,D,F,a+c
time=15
[Command]
name = "EXHEEL_a"
command =~D, DB, B, a+c
time=15
[Command]
name = "EXHEEL_b"
command =~B,D,F,a+b
time=15
[Command]
name = "EXHEEL_b"
command =~D, DB, B, a+b
time=15
[Command]
name = "EXHEEL_c"
command =~B,D,F,b+c
time=15
[Command]
name = "EXHEEL_c"
command =~D, DB, B, b+c
time=15


;ALLEY OOP
[Command]
name = "ALLEYOOP1"
command =~D, DB, B, x
time=30

[Command]
name = "ALLEYOOP2"
command =~D, DB, B, y
time=30

[Command]
name = "ALLEYOOP3"
command =~D, DB, B, z
time=30

[command]
name = "DiveKick"
command = /D, c
time = 15

[Command]
name = "DiveKick"
command = ~D, DF, F, c
time=15


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------


[Command]
name = "guardpush"
command = x+y
time = 4

[Command]
name = "guardpush"
command = y+z
time = 4

[Command]
name = "guardpush"
command = x+z
time = 4

[Command]
name = "guardpush"
command = x+y+z
time = 4 


[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1


[Command]
name = "x+a" 
command = x+a
time = 1

[Command]
name = "x+a" 
command = a+x
time = 1

[Command]
name = "z+c" 
command = $UF,z+c
time = 1
[Command]
name = "z+c" 
command = $U,z+c
time = 1
[Command]
name = "z+c" 
command = $F,z+c
time = 1
[Command]
name = "z+c" 
command = z+c
time = 1
[Command]
name = "z+c" 
command = /z+c
time = 1

;-| Dir + Button |---------------------------------------------------------

[Command]
name = "EX_JUGULARJAMB"
command = ~D, DF, F, x+y
time = 20

[Command]
name = "EX_ALLEYOOP"
command =~D, DB, B, x+z

[Command]
name = "EX_ALLEYOOP2"
command =~D, DB, B, x+y

[Command]
name = "EX_ALLEYOOP3"
command =~D, DB, B, z+y



[command]
name = "EX_DiveKick"
command = /D, a+b
time = 15

[command]
name = "EX_DiveKick"
command = /D, b+c
time = 15

[command]
name = "EX_DiveKick"
command = /D, a+c
time = 15

[command]
name = "EX_DiveKick"
command = ~DF, F, a+b
time = 15

[command]
name = "EX_DiveKick"
command = ~DF, F, b+c
time = 15

[command]
name = "EX_DiveKick"
command =~DF, F, a+c
time = 15

[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1


[Command]
name = "fwddown"
command = $FD
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;SUPERS
;---------------------------------
;+++++++++++++++++++++++++++++++++
; WRIST LOOP STRIKE SUPER
[State -1, WRIST LOOP STRIKE SUPER]
type = ChangeState
value = 3000
triggerall= command= "SUPER1" && power>=1000
triggerall = command != "holddown"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225
trigger5 = animelemtime(4)>=0&&movehit
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&movecontact
trigger10= stateno=410&&movecontact
trigger11= stateno=430&&movecontact
trigger12= stateno=450&&movecontact
trigger13= stateno=451&&movecontact
trigger14=(anim=3105&&movehit||prevstateno=3100&&movehit)
trigger15= stateno=1011&&movecontact
trigger15= Pos Y=0

; POLE VAULT KICK SUPER
[State -1, POLE VAULT KICK SUPER]
type = ChangeState
value = 3100
triggerall= statetype!=A
triggerall= Pos Y >=0
triggerall= Vel Y >=0
triggerall = command = "SUPER2" && power>=1000
triggerall=command!="holddown"
trigger1 = statetype=S&&Pos Y=0
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225
trigger5 = animelemtime(3)>=0&&movehit
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&movecontact
trigger10= stateno=410&&movecontact
trigger11= stateno=430&&movecontact
trigger12= stateno=440&&movecontact
trigger13= stateno=450&&movecontact
trigger14= stateno=451&&movecontact
trigger15= stateno=1011&&movecontact
trigger15= Pos Y=0

; CENTRIFUGE SUPER COMBO - IN THE AIR
[State -1, CENTRIFUGE SUPER]
type = ChangeState
value = 3200
triggerall= command= "SUPER2" && power>=1000
triggerall= statetype!=S&&statetype!=C
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=620&&movecontact
trigger5 = stateno=630&&movecontact
trigger6 = stateno=640&&movecontact
trigger7 = stateno=650&&movecontact
trigger8 = stateno=1010&&movecontact
trigger9 = stateno=3100&&movecontact
trigger10= stateno=3000&&movecontact
trigger11= stateno=2000&&movecontact

; PARTY WAGON SUPER
[State -1, PARTY WAGON SUPER]
type = ChangeState
value = 3300
triggerall = command= "SUPER3" && power>=3000
triggerall = command != "holddown"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225
trigger5 = animelemtime(4)>=0&&movecontact
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&movecontact
trigger10= stateno=410&&movecontact
trigger11= stateno=430&&movecontact
trigger12= stateno=450&&movecontact
trigger13= stateno=451&&movecontact
;=============================================================
;SPECIALs
;----------------------------------
;=================================
; KNOCKOUT ROLL
[State -1, KNOCKOUT ROLL]
type = ChangeState
value = 2000
triggerall= command= "KNOCKOUT1"||command= "KNOCKOUT2"||command= "KNOCKOUT3"
triggerall =command !="holddown"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225
trigger5 = animelemtime(4)>=0&&movehit
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&movecontact
trigger10= stateno=410&&movecontact
trigger11= stateno=420&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=450&&movecontact
trigger14= stateno=451&&movecontact
trigger15= stateno=1011&&movecontact
;----------------------------------
; HEEL DROP
[State -1, HEEL DROP]
type = ChangeState
value = 1000
;triggerall = command!="super jump"
triggerall = command!= "EXHEEL_a" 
triggerall = command!= "EXHEEL_b" 
triggerall = command!= "EXHEEL_c"
triggerall = command = "HEEL_a" || command = "HEEL_b" || command = "HEEL_c"
triggerall = statetype != A
triggerall = statetype=S||statetype=C
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225
trigger5 = animelemtime(1)>=3&&movehit
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&movecontact
trigger10= stateno=410&&movecontact
trigger11= stateno=420&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno=451&&movecontact
;--------------------------------------
; EX HEEL DROP
[State -1, EX HEEL DROP]
type = ChangeState
value = 1010
triggerall=power>=500
triggerall = command = "EXHEEL_a"&&command!= "EXHEEL_b" || command = "EXHEEL_b"&&command!= "EXHEEL_c" || command = "EXHEEL_c"&&command!= "EXHEEL_a"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225
trigger5 = animelemtime(1)>=3&&movehit
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&movecontact
trigger10= stateno=410&&movecontact
trigger11= stateno=420&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno=451&&movecontact

;---------------------------------------------------------------------
; Dive Kick
[State -1, Dive Kick]
type = ChangeState
value = 1020
triggerall = command!= "EX_DiveKick"
triggerall = command!= "SUPER2"
triggerall = command = "DiveKick"
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=630&&movecontact
trigger5 = stateno=640&&movecontact
trigger6 = stateno=650&&movecontact
trigger7 = anim=1010 && MoveContact
trigger7 = animelemtime(2)>=1
;---------------------------------------------------------------------------
; Dive Kick
[State -1, Dive Kick]
type = ChangeState
value = 1022
triggerall = stateno=1021
triggerall = command!= "EX_DiveKick"
triggerall = command = "DiveKick"
triggerall = statetype!=S
trigger1 = statetype!=C
trigger1 = ctrl
---------------------------------------------------------------------------
;EX Dive Kick
[State -1, EX Dive Kick]
type = ChangeState
value = 1024
triggerall = command = "EX_DiveKick"&&power>=500
triggerall = command!= "SUPER2"
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = pos y <-70
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=630&&movecontact
trigger5 = stateno=640&&movecontact
trigger6 = stateno=650&&movecontact
trigger7=stateno=1010 && MoveContact
trigger7=anim=1010
trigger7=animelemtime(6)>=1&&Pos Y <=-30
;---------------------------------------------------------------------------
;EX Dive Kick
[State -1, EX Dive Kick]
type = ChangeState
value = 1024
triggerall = var(13)<=2
triggerall = stateno=1021
triggerall = command = "EX_DiveKick"&&power>=500
triggerall = statetype!=S
trigger1 = statetype!=C
trigger1 = ctrl
trigger2=stateno=1010 && MoveContact
trigger2=anim=1010
trigger2=animelemtime(6)>=1&&Pos Y <=-30
;---------------------------------------------------------------------------
;------------------------
; JUGULAR JAMB
[State -1, JUGULAR JAMB]
type = ChangeState
value = 1700
triggerall = command = "JUGULARJAMB"
triggerall = !command= "EX_JUGULARJAMB"
triggerall = !command= "EX_OVER_EASY"
triggerall = statetype=A
trigger1=ctrl
trigger2=stateno=1010 && MoveContact
trigger2=anim=1010
trigger2=animelemtime(6)>=1&&Pos Y <=-30

; JUGULAR JAMB
[State -1, JUGULAR JAMB]
type = ChangeState
value = 1700
triggerall = command = "JUGULARJAMB"
triggerall = !command= "EX_JUGULARJAMB"
triggerall = !command= "EX_OVER_EASY"
triggerall = command!= "y"||command!="down_y"||command!="fwd_y"
triggerall = command!= "holddown"
triggerall = statetype =A
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=620&&movecontact
trigger5 = stateno=630&&movecontact
trigger6 = stateno=640&&movecontact
trigger7 = stateno=650&&movecontact
trigger8=stateno=1010 && MoveContact
trigger8=anim=1010
trigger8=animelemtime(6)>=1&&Pos Y <=-30

;EX JUGULAR JAMB
[State -1, EX JUGULAR JAMB]
type = ChangeState
value = 1800
triggerall = command = "EX_JUGULARJAMB"&&power>=500
triggerall = !command= "OVER_EASY"
triggerall = !command= "EX_OVER_EASY"
triggerall = command!= "holddown"
triggerall = statetype =A
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=620&&movecontact
trigger5 = stateno=630&&movecontact
trigger6 = stateno=640&&movecontact
trigger7 = stateno=650&&movecontact
trigger8=stateno=1010 && MoveContact
trigger8=anim=1010
trigger8=animelemtime(6)>=1&&Pos Y <=-30
;---------------------------------------------------------------------------
; OVER EASY
[State -1, OVER EASY]
type = ChangeState
value = 1600
triggerall = command = "OVER_EASY"
triggerall = !command= "EX_OVER_EASY"
triggerall = statetype=A
trigger1=ctrl
trigger2=stateno=1010 && MoveContact
trigger2=anim=1010
trigger2=animelemtime(6)>=1&&Pos Y <=-30

[State -1, OVER EASY]
type = ChangeState
value = 1600
triggerall = command = "OVER_EASY"
triggerall = !command= "EX_OVER_EASY"
triggerall = command != "z"||command!="down_z"
triggerall = command != "y"||command!="down_y"
triggerall = command!="holddown"
triggerall = statetype!=C
trigger1 =   statetype!=S
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=620&&movecontact
trigger5 = stateno=630&&movecontact
trigger6 = stateno=640&&movecontact
trigger7 = stateno=650&&movecontact
trigger8=stateno=1010 && MoveContact
trigger8=anim=1010
trigger8=animelemtime(6)>=1&&Pos Y <=-30

;EX OVER EASY
[State -1, EX OVER EASY]
type = ChangeState
value = 1630
triggerall = command = "EX_OVER_EASY"&&power>=500
triggerall = command!= "z"||command!="down_z"
triggerall = command!= "y"||command!="down_y"
triggerall = command!="holddown"
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=620&&movecontact
trigger5 = stateno=630&&movecontact
trigger6 = stateno=640&&movecontact
trigger7 = stateno=650&&movecontact
trigger8=stateno=1010 && MoveContact
trigger8=anim=1010
trigger8=animelemtime(6)>=1&&Pos Y <=-30
;---------------------------------------------------------------------------
;ALLEY OOP
;ALLEY OOP -- SWEEP
[State -1, ALLEY OOP SWEEP]
type = ChangeState
value = 1500
;triggerall = command != "holddown"
triggerall= command="ALLEYOOP1"
triggerall= command!="ALLEYOOP2"
triggerall= command!="ALLEYOOP3"
triggerall= command!="EX_ALLEYOOP"
trigger1 = statetype!=A
trigger1 = statetype =S
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225
trigger5 = animelemtime(1)>=3&&movehit
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=400&&movecontact
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=450&&movecontact
trigger12= stateno=1001
trigger12= animelemtime(1)>=3&&movecontact
trigger13= stateno=1011
trigger13= animelemtime(1)>=3&&movecontact

[State -1, ALLEY OOP MIDDLE]
type = ChangeState
value = 1500
triggerall= command="ALLEYOOP2"
triggerall= command!="ALLEYOOP1"
triggerall= command!="ALLEYOOP3"
triggerall= command!="EX_ALLEYOOP"
trigger1 = statetype!=A
trigger1 = statetype =S
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225
trigger5 = animelemtime(1)>=3&&movehit
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=400&&movecontact
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=450&&movecontact
trigger12= stateno=1001
trigger12= animelemtime(1)>=3&&movecontact
trigger13= stateno=1011
trigger13= animelemtime(1)>=3&&movecontact

;ALLEY OOP -- ANTI-AIR
[State -1, ALLEY OOP ANTI-AIR]
type = ChangeState
value = 1500
triggerall= command="ALLEYOOP3"
triggerall= command!="ALLEYOOP1"
triggerall= command!="ALLEYOOP2"
triggerall= command!="EX_ALLEYOOP"
triggerall= !command="SUPER3"
trigger1 = statetype!=A
trigger1 = statetype =S
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225
trigger5 = animelemtime(1)>=3&&movehit
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&movecontact
trigger10= stateno=410&&movecontact
trigger11= stateno=420&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=450&&movecontact


;EX ALLEY OOP
[State -1, EX ALLEY OOP]
type = ChangeState
value = 1504
triggerall= command ="EX_ALLEYOOP"&&power>=500||command="EX_ALLEYOOP2"&&power>=500||command="EX_ALLEYOOP3"&&power>=500
trigger1 = statetype!=A
trigger1 = statetype =S
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225
trigger5 = animelemtime(1)>=3&&movehit
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=250&&movecontact
trigger9 = stateno=400&&movecontact
trigger10= stateno=410&&movecontact
trigger11= stateno=420&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=450&&movecontact
trigger14= stateno=1001
trigger14= animelemtime(1)>=3&&movecontact
trigger15= stateno=1011
trigger15= animelemtime(1)>=3&&movecontact
;---------------------------------------------------------------------------
; Rolling Dodge Forward
[State -1, Rolling Dodge Forward]
type = ChangeState
value = 700
triggerall=numhelper(715)!=1
triggerall = command = "x+a"&&command="holddown" ||command="x+a" && command!="holddown" 
triggerall = command != "holdback"
trigger1 = statetype!=A
trigger1 = ctrl
;---------------------------------------------------------------------------
; Rolling Dodge Back
[State -1, Rolling Dodge Back]
type = ChangeState
value = 710
triggerall=numhelper(715)!=1
triggerall = command = "holdback" && (command = "x+a")
triggerall = command != "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype!=A
trigger1 = ctrl
;trigger2 = anim=21&&command = "holdback"
;trigger2 = command = "x+a"
;===========================================================================
;--------------------------------------------------------------------------
;Guard Push
[State -1]
type = ChangeState
value = 720
triggerall = var(10) != 1&&command = "guardpush"&&statetype = S&&p2life!=0
trigger1 = stateno = [150,153]
;-------------------------------------
[State -1]
type =ChangeState
value = 725
triggerall = var(10) != 1&&command = "guardpush"&&statetype = C&&p2life!=0
trigger1 = stateno = [150,153]
;-------------------------------------
[State -1]
type =ChangeState
value = 730 
triggerall = var(10) != 1&&command = "guardpush"&&statetype = A&&p2life!=0
trigger1 = stateno = [154,155]
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl
;==============
; Super Jump
;===============
[State -1, Super Jump]
type = ChangeState
value = 55
triggerall = command ="super jump"
trigger1 = statetype !=A
trigger1 = statetype !=C
trigger1 = ctrl = 1 || (stateno=[100,101])
;---------------------------------------------------------------------------
; Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = command = "y" || command = "z"
triggerall = statetype!=A
triggerall = statetype!=C
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype != A) 
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype != A) 
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
; Throw
[State -1, Throw]
type = ChangeState
value = 805
triggerall = command = "b" || command = "c"
triggerall = statetype!=A
triggerall = statetype!=C
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype != A)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype != A)
trigger2 = p2movetype != H
;===========================================================================
;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall =command = "s"
trigger1 = statetype != A
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command!= "ALLEYOOP1"
triggerall = command = "x"
triggerall = command != "holddown"
triggerall =  statetype!= A||statetype!=C
trigger1 = statetype = S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=230&&movecontact
trigger3 = stateno=240&&movecontact
trigger4 = anim=47&&prevstateno=440&&movehit
trigger5 = anim=0&&prevstateno=52&&movehit
trigger6 = stateno =400&&movecontact
trigger7 = stateno =430&&movecontact
;---------------------------------------------------------------------------
;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command!= "ALLEYOOP2"
triggerall = command!= "SUPER1"
triggerall = command = "y"
triggerall = command != "holddown"
triggerall =  statetype!= A||statetype!=C
trigger1 = statetype = S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno =200&& movecontact
trigger3 = stateno =230&& movecontact
trigger4 = stateno =240&&movecontact
trigger5 = stateno =400&&movecontact
trigger6 = stateno =410&&movecontact
trigger7 = stateno =430&&movecontact
;---------------------------------------------------------------------------
; Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = command!= "ALLEYOOP3"
triggerall = command!= "SUPER1"
triggerall = command = "z"
triggerall =command!="c"
triggerall = command != "holddown"
trigger1 =  statetype!= A||statetype!=C
trigger1 = statetype = S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=230&&movecontact
trigger5 = stateno=240&&movecontact
trigger6 = stateno=400&&movecontact
trigger7 = stateno=410&&movecontact
trigger8 = stateno=430&&movecontact
trigger9 = stateno=450&&movecontact
;-------------------------------------
;Stand Strong Punch 2
[State -1, Stand Strong Punch 2]
type = ChangeState
value = 225
triggerall=(stateno=220&&movehit)&&command = "z"
triggerall = command != "holddown"
triggerall = command != "SUPER1"
triggerall =  statetype!= A||statetype!=C
trigger1 = statetype =S
trigger1 = ctrl
;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
triggerall =  statetype!= A||statetype!=C
trigger1 = statetype = S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno = 200 &&movecontact
trigger3 = stateno = 220 &&movecontact
trigger4 = stateno = 225 &&movecontact
trigger4 = animelemtime(7)>=1&&movecontact
;---------------------------------------------------------------------------
;Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command!= "holddown"
triggerall = command!= "SUPER2"
triggerall = statetype!= A||statetype!=C
trigger1 = statetype = S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = (stateno = 200) && movecontact
trigger2 = time > 5
trigger3 = (stateno = 230) && movecontact
trigger3 = time > 6
trigger4 = stateno=220&&movecontact
trigger4 = p2bodydist X<=20&&(command="b"&&command!="holddown")
trigger5 = stateno=210&&movecontact
trigger6 = stateno=225&&movecontact
trigger6 = animelemtime(7)>=1&&movecontact
trigger7 = stateno=230&&movecontact
trigger8 = stateno=430&&movecontact
trigger9= numtarget(440)=1&&Pos Y=0
trigger9= movecontact
;---------------------------------------------------------------------------
; Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall =command!="z"
triggerall = command!= "holddown"
triggerall = command!= "SUPER2"
triggerall = statetype!= A||statetype!=C
trigger1 = statetype = S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=230&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=400&&movecontact
trigger8 = stateno=410&&movecontact
trigger9 = stateno=430&&movecontact
trigger10= numtarget(440)=1&&Pos Y=0
trigger10= movecontact
trigger11= stateno=450&&movecontact

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command!= "ALLEYOOP1"
triggerall = command!= "KNOCKOUT1"
triggerall = command = "x"
triggerall = command = "holddown"
triggerall = Pos Y=0
trigger1 = ctrl || (stateno=[100,101])
trigger1 = statetype!= A||statetype!=S
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=230&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=430&&movecontact
trigger8 = stateno=450&&movecontact
;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = command!= "ALLEYOOP2"
triggerall = command!= "KNOCKOUT2"
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = Pos Y=0
trigger1 = statetype!= A||statetype!=S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=230&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=400&&movecontact
trigger8 = stateno=430&&movecontact
trigger9 = stateno=450&&movecontact

;---------------------------------------------------------------------------
; Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = command!= "ALLEYOOP3"
triggerall = command!= "KNOCKOUT3"
triggerall = command = "z"
triggerall = command = "holddown"
triggerall = command!= "SUPER1"
triggerall = Pos Y=0
trigger1 = statetype!= A||statetype!=S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=410&&movecontact
trigger3 = stateno=200&&movecontact
trigger4 = stateno=210&&movecontact
trigger5 = stateno=220&&movecontact
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=225
trigger8 = animelemtime(7)>=1&&movecontact
trigger9 = stateno=400&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=450&&movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command ="holddown"
triggerall = Pos Y=0
trigger1 = statetype!=A||statetype!=S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = (stateno = 400)
trigger2 = (time > 9) || (movecontact && time > 5)
trigger3 = stateno=200&&movecontact
trigger4 = stateno=210&&movecontact
trigger5 = stateno=220&&movecontact
trigger6 = stateno=225&&movecontact
trigger6 = animelemtime(7)>=1&&movecontact
trigger7 = stateno=230&&movecontact
trigger8 = stateno=240&&movecontact
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movehit
;---------------------------------------------------------------------------
; Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command ="holddown"
triggerall = Pos Y=0
trigger1 = statetype!=A||statetype!=S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=230&&movecontact
trigger8 = stateno=231&&movecontact
trigger9 = stateno=240&&movecontact
trigger10= stateno=225
trigger10= animelemtime(7)>=1&&movecontact
trigger11= stateno=400&&movecontact
trigger12= stateno=410&&movecontact
trigger13= stateno=430&&movecontact
trigger14= stateno=450&&movecontact
;---------------------------------------------------------------------------
; Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command ="holddown"
triggerall = Pos Y=0
trigger1 = statetype!=A||statetype!=S
trigger1 = ctrl || (stateno=[100,101])
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=230&&movecontact
trigger6 = stateno=240&&movecontact
trigger7 = stateno=400&&movecontact
trigger8 = stateno=410&&movecontact
trigger9 = stateno=430&&movecontact
;---------------------------------------------------------------------------
; Crouching Strong Kick 2
[State -1, Crouching Strong Kick2]
type = ChangeState
value = 451
triggerall!= command = "SUPER2"
triggerall = command = "z+c"&&power>=500
triggerall !=command="z"
triggerall !=command="c"
triggerall = Pos Y=0
trigger1 = statetype!= A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=210&&movecontact
trigger4 = stateno=220&&movecontact
trigger5 = stateno=225&&movecontact
trigger5 =anim=225&&animelemtime(6)>=0&&movecontact
trigger6 = stateno=230&&movecontact
trigger7 = stateno=240&&movecontact
trigger8 = stateno=400&&movecontact
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=450&&movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = !command= "EX_SCRAMBLE"
triggerall = !command= "EX_JUGULARJAMB"
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking
trigger3 = stateno=610&&movecontact
trigger4 = stateno=630&&movecontact
trigger5 = stateno=640&&movecontact
;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = !command= "EX_SCRAMBLE"
triggerall = !command= "EX_JUGULARJAMB"
triggerall = !command= "EX_OVER_EASY"
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno=600||stateno = 630
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking
trigger4 = stateno=640&&movecontact


;---------------------------------------------------------------------------
; Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = command!= "OVER_EASY"
triggerall = command!= "EX_OVER_EASY"
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=630&&movecontact
trigger5 = stateno=640&&movecontact

; STAFF SCRAMBLER
[State -1, STAFF SCRAMBLER]
type = ChangeState
value = 621
triggerall = command!= "OVER_EASY"
triggerall = command!= "EX_OVER_EASY"
triggerall= Pos Y<=-30
triggerall = statetype =A
triggerall = statetype!=S
triggerall = ctrl
trigger1 = command!= "OVER_EASY"
trigger1 =(StateNo = 620) && MoveContact
trigger1 =animelemtime(4)>=1&&command = "z"
trigger2 = command!= "OVER_EASY"
trigger2 = (StateNo = 650) && MoveContact
trigger2 = animelemtime(2)>=1&&command = "z"

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking
trigger3 = stateno=600&&movecontact
trigger4 = stateno=610&&movecontact
trigger5 = stateno=640&&movecontact

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = command!= "EX_DiveKick"
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking
trigger3 = stateno=600&&movecontact
trigger4 = stateno=610&&movecontact
trigger5 = stateno=630&&movecontact

;---------------------------------------------------------------------------
; Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = command!= "DiveKick"
triggerall = command!= "EX_DiveKick"
triggerall = command = "c"
triggerall = command!= "holddown"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger3 = stateno=610&&movecontact
trigger4 = stateno=620&&movecontact
trigger5 = stateno=630&&movecontact
trigger6 = stateno=640&&movecontact


